@@ -1,102 +1,7 @@
 package Carton;
-
 use strict;
-use warnings;
 use 5.008_005;
-use version; our $VERSION = version->declare("v0.9.53");
-
-use Config qw(%Config);
-use Carton::Builder;
-use Carton::Mirror;
-use Carton::Util;
-use CPAN::Meta;
-use File::Spec ();
-
-use constant CARTON_LOCK_VERSION => '0.9';
-
-sub new {
-    my($class, %args) = @_;
-    bless {
-        path => $ENV{PERL_CARTON_PATH} || 'local',
-        mirror => $ENV{PERL_CARTON_MIRROR} || $Carton::Mirror::DefaultMirror,
-    }, $class;
-}
-
-sub local_cache {
-    File::Spec->rel2abs("vendor/cache");
-}
-
-sub bundle {
-    my($self, $cpanfile, $lock) = @_;
-
-    $lock->write_index($self->{mirror_file});
-
-    my $builder = Carton::Builder->new(
-        mirror => Carton::Mirror->new($self->{mirror}),
-        index  => $self->{mirror_file},
-    );
-
-    $builder->bundle($self->local_cache);
-}
-
-sub install {
-    my($self, $file, $lock, $cascade, $cached) = @_;
-
-    # TODO merge CPANfile git to mirror even if lock doesn't exist
-    if ($lock) {
-        $lock->write_index($self->{mirror_file});
-    }
-
-    my $mirror  = Carton::Mirror->new($cached ? $self->local_cache : $self->{mirror});
-    my $builder = Carton::Builder->new(
-        mirror => $mirror,
-        index  => $lock ? $self->{mirror_file} : undef,
-    );
-
-    $builder->install($self->{path}, $cascade);
-}
-
-sub update_lock_file {
-    my($self, $file) = @_;
-
-    my $lock = $self->build_lock;
-    Carton::Lock->new($lock)->write($file);
-
-    return 1;
-}
-
-sub build_lock {
-    my $self = shift;
-
-    my %installs = $self->find_installs;
-
-    return {
-        modules => \%installs,
-        version => CARTON_LOCK_VERSION,
-    };
-}
-
-sub find_installs {
-    my $self = shift;
-
-    require File::Find;
-
-    my $libdir = "$self->{path}/lib/perl5/$Config{archname}/.meta";
-    return unless -e $libdir;
-
-    my @installs;
-    my $wanted = sub {
-        if ($_ eq 'install.json') {
-            push @installs, [ $File::Find::name, "$File::Find::dir/MYMETA.json" ];
-        }
-    };
-    File::Find::find($wanted, $libdir);
-
-    return map {
-        my $module = Carton::Util::load_json($_->[0]);
-        my $mymeta = -f $_->[1] ? CPAN::Meta->load_file($_->[1])->as_struct({ version => "2" }) : {};
-        ($module->{name} => { %$module, mymeta => $mymeta }) } @installs;
-}
+use version; our $VERSION = version->declare("v0.9.54");
 
 1;
 __END__
